[libdist-zilla-plugin-test-eol-perl] 06/07: formally deprecate [EOLTests]

Intrigeri intrigeri at moszumanska.debian.org
Sun Aug 16 09:20:20 UTC 2015


This is an automated email from the git hooks/post-receive script.

intrigeri pushed a commit to annotated tag 0.14
in repository libdist-zilla-plugin-test-eol-perl.

commit 2cbf661950e8e2428e1b7a5f6e993e06c6382f53
Author: Karen Etheridge <ether at cpan.org>
Date:   Wed Oct 22 17:34:56 2014 -0700

    formally deprecate [EOLTests]
---
 Changes                           |  2 ++
 lib/Dist/Zilla/Plugin/EOLTests.pm | 13 ++++++++++++-
 t/02-eoltests.t                   |  1 +
 3 files changed, 15 insertions(+), 1 deletion(-)

diff --git a/Changes b/Changes
index 001dc07..381635b 100644
--- a/Changes
+++ b/Changes
@@ -4,6 +4,8 @@ Revision history for {{$dist->name}}
         - change default filename from test-eol.t to eol.t
         - add metadata for [MetaConfig]
         - fix missing test prerequisite
+        - formally deprecated [EOLTests] (it will continue to exist through
+          April 2015).
 
 0.13      2014-10-22 05:44:36Z
         - Dist::Zilla::Plugin::EOLTests and Dist::Zilla::Plugin::Test::EOL are
diff --git a/t/02-eoltests.t b/t/02-eoltests.t
index 2c397cf..bf1af4b 100644
--- a/t/02-eoltests.t
+++ b/t/02-eoltests.t
@@ -6,6 +6,7 @@ use warnings FATAL => 'all';
 use Path::Tiny;
 my $code = path('t', '01-basic.t')->slurp_utf8;
 
+$code =~ s/use if \$ENV\{AUTHOR_TESTING\}, 'Test::Warnings';//;
 $code =~ s/Test::EOL(?!'\s*=>)/EOLTests/g;
 $code =~ s{xt(.)author(.)eol\.t}{xt$1release$2eol.t}g;
 

diff --git a/lib/Dist/Zilla/Plugin/EOLTests.pm b/lib/Dist/Zilla/Plugin/EOLTests.pm
index 221b53b..366ec9f 100644
--- a/lib/Dist/Zilla/Plugin/EOLTests.pm
+++ b/lib/Dist/Zilla/Plugin/EOLTests.pm
@@ -1,12 +1,16 @@
 use strict;
 use warnings;
 package Dist::Zilla::Plugin::EOLTests;
 # ABSTRACT: Release tests making sure correct line endings are used
 
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::EOL';
 use namespace::autoclean;
 
+before register_component => sub {
+    warn "!!! [EOLTests] is deprecated and may be removed in a future release; replace it with [Test::EOL] (note the different default filename)\n";
+};
+
 has '+filename' => (
     default => sub { return 'xt/release/eol.t' },
 );
@@ -28,4 +32,11 @@ In your F<dist.ini>:
 This is a plugin that runs at the L<gather files|Dist::Zilla::Role::FileGatherer> stage,
 providing the file F<xt/release/eol.t>, a standard L<Test::EOL> test.
 
+THIS MODULE IS DEPRECATED. Please use
+L<Dist::Zilla::Plugin::Test::EOL> instead. it may be removed at a
+later time (but not before April 2015).
+
+In the meantime, it will continue working -- although with a warning.
+Refer to the replacement for the full documentation.
+
 =cut
@@ -1,12 +1,16 @@
 use warnings;
 package Dist::Zilla::Plugin::EOLTests;
-# ABSTRACT: Release tests making sure correct line endings are used
+# ABSTRACT: (DEPRECATED) Release tests making sure correct line endings are used
 
 use Moose;
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-perl/packages/libdist-zilla-plugin-test-eol-perl.git



More information about the Pkg-perl-cvs-commits mailing list